@@ -1,11 +1,11 @@
 ;;; sb-itmedia.el --- shimbun backend for ITmedia -*- coding: iso-2022-7bit -*-
 
-;; Copyright (C) 2004, 2005, 2006, 2007, 2008, 2009, 2010
-;; Yuuichi Teranishi <teranisi@gohome.org>
+;; Copyright (C) 2004-2011 Yuuichi Teranishi <teranisi@gohome.org>
 
 ;; Author: TSUCHIYA Masatoshi <tsuchiya@namazu.org>,
-;;         Yuuichi Teranishi  <teranisi@gohome.org>
-;;         ARISAWA Akihiro    <ari@mbf.sphere.ne.jp>
+;;         Yuuichi Teranishi  <teranisi@gohome.org>,
+;;         ARISAWA Akihiro    <ari@mbf.sphere.ne.jp>,
+;;         Katsumi Yamaoka    <yamaoka@jpl.org>
 ;; Keywords: news
 
 ;; This file is a part of shimbun.
@@ -138,8 +138,8 @@ R[TQ[*i0d##D=I3|g`2yr@sc<pK1SB
 	  (delete-region (match-beginning 0) (point-max)))
 	(goto-char (point-min))
 	(setq regexp (if (string-equal group "kodera")
-			 "<a[\t\n ]+href=\"\
-\\(http://plusd\\.itmedia\\.co\\.jp/[^\"]+/articles/\
+			 "<a[\t\n ]+href=\"\\(http://\
+\\(?:plusd\\.itmedia\\|monoist\\.atmarkit\\)\\.co\\.jp/[^\"]+/articles/\
 \\([0-9][0-9]\\)\\([01][0-9]\\)/\\([0-3][0-9]\\)/news\\([0-9]+\\)\\.html\\)\
 \"[\t\n ]*>\\(?:[\t\n ]*\\|[\t\n ]*<strong>[\t\n ]*\\)\\([^<]+\\)"
 		       "<a[\t\n ]+href=\"\
@@ -223,43 +223,62 @@ R[TQ[*i0d##D=I3|g`2yr@sc<pK1SB
 						    header)
   (or (luna-call-next-method)
       (prog1
-	  (let ((case-fold-search t)
-		icon start)
-	    (goto-char (point-min))
-	    (when (and (re-search-forward "<div\\(?:[\t\n ]+[^\t\n >]+\\)*\
-\[\t\n ]+class=\"article-icon\""
-					  nil t)
-		       (shimbun-end-of-tag "div"))
-	      (setq icon (match-string 0)))
-	    (goto-char (point-min))
-	    (when (and (search-forward "<!--BODY-->" nil t)
-		       (progn
-			 (setq start (match-end 0))
-			 (when (and (re-search-backward "<h[0-9]>[^<]+</h[0-9]>"
-							nil t)
-				    (progn
-				      (goto-char (match-end 0))
-				      (not (re-search-forward "<h[0-9]>" start t))))
-			   (delete-region (match-end 0) start)
-			   (setq start (match-beginning 0)))
-			 (re-search-forward "<!--BODY ?END-->" nil t)))
-	      (delete-region (match-beginning 0) (point-max))
-	      (delete-region (point-min) start)
-	      ;; Remove anchors to both the next page and the previous page.
-	      ;; These anchors are inserted into the head and the tail of the
-	      ;; article body.
-	      (skip-chars-backward " \t\r\f\n")
-	      (forward-line 0)
-	      (when (looking-at "<P ALIGN=\"CENTER\"><[AB]")
-		(delete-region (point) (point-max)))
-	      (goto-char (point-min))
-	      (skip-chars-forward " \t\r\f\n")
-	      (when (looking-at "<P ALIGN=\"CENTER\"><[AB]")
-		(delete-region (point-min) (point-at-eol)))
-	      (when icon
+	  ;; Extract the article body and return t if successful.
+	  (if (string-match "\\`http://monoist\\.atmarkit\\.co\\.jp/"
+			    (shimbun-header-xref header))
+	      (let ((case-fold-search t)
+		    start)
 		(goto-char (point-min))
-		(insert icon "\n"))
-	      t))
+		(when (re-search-forward "\
+<div[\t\n ]+\\(?:[^\t\n >]+[\t\n ]+\\)*id=\"cmsAbstract\"" nil t)
+		  (setq start (match-beginning 0)))
+		(when (and (re-search-forward "\
+<div[\t\n ]+\\(?:[^\t\n >]+[\t\n ]+\\)*id=\"cmsBody\"" nil t)
+			   (shimbun-end-of-tag "div" t))
+		  (delete-region (match-end 0) (point-max))
+		  (delete-region (point-min) (or start (match-beginning 0)))
+		  (goto-char (point-max))
+		  (insert "\n")
+		  t))
+	    (let ((case-fold-search t)
+		  icon start)
+	      (goto-char (point-min))
+	      (when (and (re-search-forward "<div\\(?:[\t\n ]+[^\t\n >]+\\)*\
+\[\t\n ]+class=\"article-icon\""
+					    nil t)
+			 (shimbun-end-of-tag "div"))
+		(setq icon (match-string 0)))
+	      (goto-char (point-min))
+	      (when (and (search-forward "<!--BODY-->" nil t)
+			 (progn
+			   (setq start (match-end 0))
+			   (when (and (re-search-backward
+				       "<h[0-9]>[^<]+</h[0-9]>" nil t)
+				      (progn
+					(goto-char (match-end 0))
+					(not (re-search-forward "<h[0-9]>"
+								start t))))
+			     (delete-region (match-end 0) start)
+			     (setq start (match-beginning 0)))
+			   (re-search-forward "<!--BODY ?END-->" nil t)))
+		(delete-region (match-beginning 0) (point-max))
+		(delete-region (point-min) start)
+		;; Remove anchors to both the next page and the previous page.
+		;; These anchors are inserted into the head and the tail of
+		;; the article body.
+		(skip-chars-backward " \t\r\f\n")
+		(forward-line 0)
+		(when (looking-at "<P ALIGN=\"CENTER\"><[AB]")
+		  (delete-region (point) (point-max)))
+		(goto-char (point-min))
+		(skip-chars-forward " \t\r\f\n")
+		(when (looking-at "<P ALIGN=\"CENTER\"><[AB]")
+		  (delete-region (point-min) (point-at-eol)))
+		(when icon
+		  (goto-char (point-min))
+		  (insert icon "\n"))
+		t)))
+	(shimbun-remove-tags "<!-- ad_start_new -->" "<!-- ad_end_new -->")
 	(shimbun-remove-tags "<!-- AD START -->" "<!-- AD END -->")
 	(shimbun-remove-tags "\
 <IMG [^>]*SRC=\"http:/[^\"]*/\\(ad\\.itmedia\\.co\\.jp\\|\
@@ -291,7 +310,8 @@ a1100\\.g\\.akamai\\.net\\)/[^>]+>[^<]*</A>")
 				       (match-beginning 1) t))
 	      (goto-char (match-end 0)))
 	    (unless
-		;; Check if there's a tag that is likely to cause the line-break.
+		;; Check if there's a tag that is likely to cause
+		;; the line-break.
 		(looking-at "\\(?:<![^>]+>[\t\n ]*\\)*\
 <\\(?:br\\|div\\|h[0-9]+\\|p\\)\\(?:[\t\n ]*>\\|[\t\n ]\\)")
 	      (replace-match "\\1<br>\n"))))
