@@ -325,7 +325,9 @@ slot of SHIMBUN to encode URL."
 (defalias 'shimbun-end-of-tag 'w3m-end-of-tag)
 (defalias 'shimbun-expand-url 'w3m-expand-url)
 (defalias 'shimbun-find-coding-system 'w3m-find-coding-system)
+(defalias 'shimbun-interactive-p 'w3m-interactive-p)
 (defalias 'shimbun-replace-in-string 'w3m-replace-in-string)
+(defalias 'shimbun-switch-to-buffer 'w3m-switch-to-buffer)
 (defalias 'shimbun-url-encode-string 'w3m-url-encode-string)
 
 ;;; Implementation of Header API.
@@ -1817,38 +1819,40 @@ There are exceptions; some chars aren't converted, and \"$B!c(B\", \"$B!d(B\
 
 (defun shimbun-xml-parse-buffer ()
   "Calls (lib)xml-parse-region on the whole buffer.
-This is a wrapper for xml-parse-region, which will resort to
-using libxml-parse-xml-region if available, since it is much
+This is a wrapper for `xml-parse-region', which will resort to
+using `libxml-parse-xml-region' if available, since it is much
 faster."
   (if (fboundp 'libxml-parse-xml-region)
       (save-excursion
 	(goto-char (point-min))
 	(let ((xml (libxml-parse-xml-region
 		    (1- (search-forward "<" nil t)) (point-max)))
-	      (start 0)
-	      (stylestring
-	       (progn (goto-char (point-min))
-		      (when (re-search-forward "<\\(rss\\|feed\\)\\(.*?\\)>" nil t)
-			(match-string 2))))
-	      stylesheet)
-	  ;; Parse the stylesheet
-	  (when stylestring
-	    (while (string-match "\\(xmlns:?.*?\\)=\"\\(.*?\\)\"" stylestring start)
-	      (setq start (match-end 0))
-	      (push (cons (intern (match-string 1 stylestring))
-			  (match-string 2 stylestring))
-		    stylesheet)))
-	  ;; Add stylesheet into XML structure
-	  (when stylesheet
-	    (if (nth 1 xml)
-		(nconc (nth 1 xml) stylesheet)
-	      (setcar (cdr xml) stylesheet)))
-	  (list xml)))
+	      start stylestring stylesheet)
+	  (if xml
+	      (progn
+		;; Parse the stylesheet
+		(goto-char (point-min))
+		(when (re-search-forward "<\\(rss\\|feed\\)\\(.*?\\)>"
+					 nil t)
+		  (setq stylestring (match-string 2)
+			start 0)
+		  (while (string-match "\\(xmlns:?.*?\\)=\"\\(.*?\\)\""
+				       stylestring start)
+		    (setq start (match-end 0))
+		    (push (cons (intern (match-string 1 stylestring))
+				(match-string 2 stylestring))
+			  stylesheet)))
+		;; Add stylesheet into XML structure
+		(when stylesheet
+		  (if (nth 1 xml)
+		      (nconc (nth 1 xml) stylesheet)
+		    (setcar (cdr xml) stylesheet)))
+		(list xml))
+	    ;; Unfortunately libxml failed parsing for some reason.
+	    (xml-parse-region (point-min) (point-max)))))
     ;; We don't have libxml, so just use the slow one.
     (xml-parse-region (point-min) (point-max))))
 
-
-
 (provide 'shimbun)
 
 ;;; shimbun.el ends here
