@@ -1,7 +1,6 @@
 ;;; w3m-ems.el --- GNU Emacs stuff for emacs-w3m
 
-;; Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010
-;; TSUCHIYA Masatoshi <tsuchiya@namazu.org>
+;; Copyright (C) 2001-2011 TSUCHIYA Masatoshi <tsuchiya@namazu.org>
 
 ;; Authors: Yuuichi Teranishi  <teranisi@gohome.org>,
 ;;          TSUCHIYA Masatoshi <tsuchiya@namazu.org>,
@@ -106,12 +105,15 @@
 Return the first possible coding system.
 
 PRIORITY-LIST is a list of coding systems ordered by priority."
-  (let (category categories)
-    (dolist (codesys priority-list)
-      (setq category (coding-system-category codesys))
-      (unless (or (null category) (assq category categories))
-	(push (cons category codesys) categories)))
-    (car (detect-coding-with-priority start end (nreverse categories)))))
+  (w3m-static-if (fboundp 'with-coding-priority)
+      (with-coding-priority priority-list
+	(car (detect-coding-region start end)))
+    (let (category categories)
+      (dolist (codesys priority-list)
+	(setq category (coding-system-category codesys))
+	(unless (or (null category) (assq category categories))
+	  (push (cons category codesys) categories)))
+      (car (detect-coding-with-priority start end (nreverse categories))))))
 
 (defun w3m-mule-unicode-p ()
   "Check the existence as charsets of mule-unicode."
@@ -134,27 +136,29 @@ This function is an interface to `define-coding-system'."
 		      :mnemonic mnemonic :coding-type 'ccl
 		      :ccl-decoder decoder :ccl-encoder encoder))))
     (eval-when-compile
-      (funcall (if (featurep 'bytecomp)
-		   (lambda (form)
-		     (let ((byte-compile-warnings
-			    (if (eq (get 'make-coding-system 'byte-compile)
-				    'byte-compile-obsolete)
-				(delq 'obsolete
-				      (copy-sequence
-				       (cond ((consp byte-compile-warnings)
-					      byte-compile-warnings)
-					     (byte-compile-warnings
-					      byte-compile-warning-types)
-					     (t nil))))
-			      byte-compile-warnings)))
-		       (byte-compile form)))
-		 'identity)
-	       '(lambda (coding-system mnemonic docstring decoder encoder) "\
+      (funcall
+       (if (featurep 'bytecomp)
+	   (lambda (form)
+	     (let ((byte-compile-warnings
+		    (if (or (get 'make-coding-system 'byte-obsolete-info)
+			    (eq (get 'make-coding-system 'byte-compile)
+				'byte-compile-obsolete))
+			(delq 'obsolete
+			      (copy-sequence
+			       (cond ((consp byte-compile-warnings)
+				      byte-compile-warnings)
+				     (byte-compile-warnings
+				      byte-compile-warning-types)
+				     (t nil))))
+		      byte-compile-warnings)))
+	       (byte-compile form)))
+	 'identity)
+       '(lambda (coding-system mnemonic docstring decoder encoder) "\
 Define a new CODING-SYSTEM by CCL programs DECODER and ENCODER.
 CODING-SYSTEM, DECODER and ENCODER must be symbols.
 This function is an interface to `make-coding-system'."
-		  (make-coding-system coding-system 4 mnemonic docstring
-				      (cons decoder encoder)))))))
+	  (make-coding-system coding-system 4 mnemonic docstring
+			      (cons decoder encoder)))))))
 
 ;; For Emacsen of which the `mule-version' is 5.x, redefine the ccl
 ;; programs that been defined in w3m-ccl.el.
@@ -533,9 +537,10 @@ variable or both the value of this variable and the global value of
   ;; Invalidate the default bindings.
   (let ((keys (cdr (key-binding [tool-bar] t)))
 	item)
-    (while (setq item (pop keys))
-      (when (setq item (car-safe item))
-	(define-key keymap (vector 'tool-bar item) 'undefined))))
+    (unless (eq (caar keys) 'keymap) ;; Emacs >= 24
+      (while (setq item (pop keys))
+	(when (setq item (car-safe item))
+	  (define-key keymap (vector 'tool-bar item) 'undefined)))))
   (let ((n (length defs))
 	def)
     (while (>= n 0)
@@ -839,13 +844,13 @@ Wobble the selected window to force redisplay of the header-line."
 	(setq window (next-window))))
     (unless (eq (window-buffer window) buffer)
       (select-window window)
-      (switch-to-buffer buffer)
+      (w3m-switch-to-buffer buffer)
       (w3m-force-window-update window))))
 
 (defun w3m-tab-click-mouse-function (event buffer)
   (let ((window (posn-window (event-start event))))
     (select-window window)
-    (switch-to-buffer buffer)
+    (w3m-switch-to-buffer buffer)
     (w3m-force-window-update window)))
 
 (defun w3m-tab-double-click-mouse1-function (event buffer)
@@ -972,7 +977,7 @@ is non-nil means not to respond to too fast operation of mouse wheel."
   (unless n (setq n 1))
   (when (and (/= n 0) (eq major-mode 'w3m-mode))
     (let ((buffers (w3m-list-buffers)))
-      (switch-to-buffer
+      (w3m-switch-to-buffer
        (nth (mod (+ n (w3m-buffer-number (current-buffer)) -1)
 		 (length buffers))
 	    buffers))
@@ -1028,7 +1033,7 @@ is non-nil means not to respond to too fast operation of mouse wheel."
 	   (f2 (lambda (fn) `(lambda (e)
 			       (interactive "e")
 			       (select-window (posn-window (event-start e)))
-			       (switch-to-buffer ,cur)
+			       (w3m-switch-to-buffer ,cur)
 			       (setq this-command ',fn)
 			       (,fn 1 e))))
 	   (drag-action (funcall f1 'w3m-tab-drag-mouse-function))
