@@ -1,6 +1,6 @@
 ;;; w3m-favicon.el --- utilities for handling favicon in emacs-w3m
 
-;; Copyright (C) 2001, 2002, 2003, 2004, 2005, 2007
+;; Copyright (C) 2001, 2002, 2003, 2004, 2005, 2007, 2009
 ;; TSUCHIYA Masatoshi <tsuchiya@namazu.org>
 
 ;; Authors: Yuuichi Teranishi  <teranisi@gohome.org>,
@@ -307,11 +307,13 @@ stored in the `w3m-favicon-image' buffer-local variable."
 	(w3m-favicon-set-image (w3m-favicon-cache-favicon url)))
     (lexical-let ((url url)
 		  (type type)
-		  (target target))
+		  (target target)
+		  (silent w3m-message-silent))
       (w3m-process-with-null-handler
 	(w3m-process-do-with-temp-buffer
 	    (ok (w3m-retrieve url 'raw nil nil nil handler))
-	  (let (idata image)
+	  (let ((w3m-message-silent silent)
+		idata image)
 	    (if (and ok
 		     ;; Some broken servers provides empty contents.
 		     (>= (buffer-size) 4))
