@@ -1,7 +1,6 @@
 ;;; w3m-form.el --- Stuffs to handle <form> tag
 
-;; Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010
-;; TSUCHIYA Masatoshi <tsuchiya@namazu.org>
+;; Copyright (C) 2001-2011 TSUCHIYA Masatoshi <tsuchiya@namazu.org>
 
 ;; Authors: TSUCHIYA Masatoshi <tsuchiya@namazu.org>,
 ;;          Yuuichi Teranishi  <teranisi@gohome.org>,
@@ -1371,7 +1370,7 @@ selected rather than \(as usual\) some other window.  See
 				    w3m-form-input-textarea-buffer-lines))))
 	(select-window (next-window)))
       (let ((pop-up-windows nil))
-	(switch-to-buffer (if (consp buffer) (cdr buffer) buffer))))))
+	(w3m-switch-to-buffer (if (consp buffer) (cdr buffer) buffer))))))
 
 (defun w3m-form-use-textarea-backup-p ()
   (and w3m-form-use-textarea-backup
@@ -1654,7 +1653,7 @@ selected rather than \(as usual\) some other window.  See
 				  w3m-form-input-select-buffer-lines))))
       (select-window (next-window))
       (let ((pop-up-windows nil))
-	(switch-to-buffer (if (consp buffer) (cdr buffer) buffer))))))
+	(w3m-switch-to-buffer (if (consp buffer) (cdr buffer) buffer))))))
 
 ;;; MAP
 
@@ -1810,7 +1809,7 @@ selected rather than \(as usual\) some other window.  See
 				  w3m-form-input-map-buffer-lines))))
       (select-window (next-window))
       (let ((pop-up-windows nil))
-	(switch-to-buffer (if (consp buffer) (cdr buffer) buffer))))))
+	(w3m-switch-to-buffer (if (consp buffer) (cdr buffer) buffer))))))
 
 ;;;
 (defun w3m-form-submit-get-textarea-files (form)
