@@ -1,7 +1,6 @@
 ;;; w3m-util.el --- Utility macros and functions for emacs-w3m
 
-;; Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010,
-;; 2011  TSUCHIYA Masatoshi <tsuchiya@namazu.org>
+;; Copyright (C) 2001-2011 TSUCHIYA Masatoshi <tsuchiya@namazu.org>
 
 ;; Authors: TSUCHIYA Masatoshi <tsuchiya@namazu.org>,
 ;;          Shun-ichi GOTO     <gotoh@taiyo.co.jp>,
@@ -531,6 +530,22 @@ the tabs line."
 	(when (eq cbuf buf)
 	  (throw 'exist bufs))))))
 
+(defun w3m-switch-to-buffer (buffer-or-name &optional norecord)
+  "Switch to buffer BUFFER-OR-NAME in the selected window.
+Optional argument NORECORD non-nil means do not put the buffer
+specified by BUFFER-OR-NAME at the front of the buffer list and
+do not make the window displaying it the most recently selected
+one.  Return the buffer switched to.
+
+This function is intended for the non-interactive use."
+  (let ((buffer (or (get-buffer buffer-or-name)
+		    (generate-new-buffer buffer-or-name))))
+    (set-window-buffer nil buffer)
+    (set-buffer buffer)
+    (unless norecord
+      (select-window (selected-window)))
+    buffer))
+
 (defmacro w3m-popup-window-p ()
   "Return non-nil if `w3m-pop-up-windows' is non-nil and the present
 situation allows it."
@@ -583,7 +598,7 @@ according to `w3m-pop-up-windows' and `w3m-pop-up-frames' (which see)."
 		 (setq w3m-initial-frames
 		       (prog1
 			   (copy-sequence w3m-initial-frames)
-			 (switch-to-buffer buffer))))
+			 (w3m-switch-to-buffer buffer))))
 		(frame
 		 ;; Pop up the existing frame which shows BUFFER.
 		 (pop-to-buffer buffer))
@@ -607,7 +622,7 @@ according to `w3m-pop-up-windows' and `w3m-pop-up-frames' (which see)."
 		(if (w3m-popup-window-p)
 		    (let ((pop-up-windows t))
 		      (pop-to-buffer buffer))
-		  (switch-to-buffer buffer)))
+		  (w3m-switch-to-buffer buffer)))
 	(w3m-history-restore-position)))))
 
 (eval-when-compile
@@ -1406,10 +1421,10 @@ The value of DEFAULT is inserted into PROMPT."
 	  (cadr c)
 	  (if (nth 3 c)
 	      `(progn
-		 (switch-to-buffer w3m-tab-button-menu-current-buffer)
+		 (w3m-switch-to-buffer w3m-tab-button-menu-current-buffer)
 		 (funcall (function ,(car c)) ,@(nthcdr 4 c)))
 	    `(save-window-excursion
-	       (switch-to-buffer w3m-tab-button-menu-current-buffer)
+	       (w3m-switch-to-buffer w3m-tab-button-menu-current-buffer)
 	       (funcall (function ,(car c)) ,@(nthcdr 4 c))))
 	  :active (nth 2 c)
 	  :keys (or (and (assq (car c) w3m-make-menu-commands-keys)
@@ -1452,6 +1467,17 @@ get to be the alias to `visited-file-modtime'."
 	  (t
 	   modtime))))
 
+(defmacro w3m-interactive-p ()
+  (condition-case nil
+      (progn
+	(eval '(called-interactively-p 'any))
+	;; Emacs >=23.2
+	'(called-interactively-p 'any))
+    ;; Emacs <23.2
+    (wrong-number-of-arguments '(called-interactively-p))
+    ;; Old ones
+    (void-function '(interactive-p))))
+
 ;;; Punycode RFC 3492:
 
 (defconst w3m-puny-code-regex "xn--\\([-0-9a-zA-z]+\\)")
